@@ -18,15 +18,20 @@
 
 __author__ = """Francisco Fernandez"""
 __email__ = "fernandezfrancisco2195@gmail.com"
-__version__ = "0.3.6"
+__version__ = "0.4.0"
 
 
 # ============================================================================
 # IMPORTS
 # ============================================================================
 
-# pair analyzer
-from .distances import pbc  # noqa
+# core
+from .core import AtomicSystem  # noqa
+
+# distances
+from .distances import pbc_distances  # noqa
+
+# molecular dynamics observables
 from .msd import MeanSquareDisplacement  # noqa
 from .rdf import RadialDistributionFunction  # noqa
 from .cn import CoordinationNumber  # noqa
@@ -45,6 +50,3 @@ from .io import *  # noqa
 from .io.reader import XYZ, LAMMPS, read_log_lammps  # noqa
 from .io.writer import XYZ, LAMMPS, in_lammps  # noqa
 from .io.positions import Positions, spherical_nanoparticle, replicate  # noqa
-
-# core private
-from .core import _is_sorted, _sort_traj  # noqa
